/***************************************************************************
*   Copyright (C) 2003 by Sandro Giessl                                   *
*   Copyright (C) 2005 by Gábor Lehel                                     *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
***************************************************************************/

#include <qbuttongroup.h>
#include <qcheckbox.h>
#include <qcombobox.h>
#include <qradiobutton.h>
#include <qslider.h>
#include <qspinbox.h>
#include <qwhatsthis.h>

#include <kconfig.h>
#include <klocale.h>
#include <kglobal.h>

#include "config.h"
#include "configdialog.h"

flatKniftyConfig::flatKniftyConfig(KConfig* config, QWidget* parent)
    : QObject(parent), m_config(0), m_dialog(0)
{
    // create the configuration object
    m_config = new KConfig("kwinflatkniftyrc");
    KGlobal::locale()->insertCatalogue("kwin_flatknifty_config");

    // create and show the configuration dialog
    m_dialog = new ConfigDialog(parent);
    m_dialog->show();

    // load the configuration
    load(config);

    // setup the connections
    connect(m_dialog->titleAlign, SIGNAL(clicked(int)),
            this, SIGNAL(changed()));
    connect(m_dialog->highContrastButtons, SIGNAL(highlighted(int)),
            this, SIGNAL(changed()));
    connect(m_dialog->bordersOnButtons, SIGNAL(highlighted(int)),
            this, SIGNAL(changed()));
    connect(m_dialog->designatedTitlebarColor, SIGNAL(toggled(bool)),
            this, SIGNAL(changed()));
    connect(m_dialog->bordersBlendColor, SIGNAL(toggled(bool)),
            this, SIGNAL(changed()));
    connect(m_dialog->titleShadow, SIGNAL(toggled(bool)),
            this, SIGNAL(changed()));
}

flatKniftyConfig::~flatKniftyConfig()
{
    if (m_dialog) delete m_dialog;
    if (m_config) delete m_config;
}

void flatKniftyConfig::load(KConfig*)
{
    m_config->setGroup("General");


    QString value = m_config->readEntry("TitleAlignment", "AlignHCenter");
    QRadioButton *button = static_cast<QRadioButton*>(m_dialog->titleAlign->child(value));
    if (button) button->setChecked(true);
    int highContrastButtons = m_config->readNumEntry("UseHighContrastButtons", 1 /*WhenHovered*/);
    m_dialog->highContrastButtons->setCurrentItem(highContrastButtons);
    int bordersOnButtons = m_config->readNumEntry("DrawBordersOnButtons", 1 /*WhenHovered*/);
    m_dialog->bordersOnButtons->setCurrentItem(bordersOnButtons);
    bool designatedTitlebarColor = m_config->readBoolEntry("UseTitleBarColor", true);
    m_dialog->designatedTitlebarColor->setChecked(designatedTitlebarColor);
    bool bordersBlendColor = m_config->readBoolEntry("BordersBlendColor", false);
    m_dialog->bordersBlendColor->setChecked(bordersBlendColor);
    bool titleShadow = m_config->readBoolEntry("TitleShadow", false);
    m_dialog->titleShadow->setChecked(titleShadow);
}

void flatKniftyConfig::save(KConfig*)
{
    m_config->setGroup("General");

    QRadioButton *button = static_cast<QRadioButton*>(m_dialog->titleAlign->selected());
    if (button) m_config->writeEntry("TitleAlignment", QString(button->name()));
    m_config->writeEntry("UseHighContrastButtons", m_dialog->highContrastButtons->currentItem() );
    m_config->writeEntry("DrawBordersOnButtons", m_dialog->bordersOnButtons->currentItem() );
    m_config->writeEntry("UseTitleBarColor", m_dialog->designatedTitlebarColor->isChecked() );
    m_config->writeEntry("BordersBlendColor", m_dialog->bordersBlendColor->isChecked() );
    m_config->writeEntry("TitleShadow", m_dialog->titleShadow->isChecked() );
    m_config->sync();
}

void flatKniftyConfig::defaults()
{
    QRadioButton *button =
        static_cast<QRadioButton*>(m_dialog->titleAlign->child("AlignHCenter"));
    if (button) button->setChecked(true);
    m_dialog->highContrastButtons->setCurrentItem(1 /*WhenHovered*/);
    m_dialog->bordersOnButtons->setCurrentItem(1 /*WhenHovered*/);
    m_dialog->designatedTitlebarColor->setChecked(true);
    m_dialog->bordersBlendColor->setChecked(false);
    m_dialog->titleShadow->setChecked(false);
}

//////////////////////////////////////////////////////////////////////////////
// Plugin Stuff                                                             //
//////////////////////////////////////////////////////////////////////////////

extern "C"
{
    KDE_EXPORT QObject* allocate_config(KConfig* config, QWidget* parent) {
        return (new flatKniftyConfig(config, parent));
    }
}

#include "config.moc"
